@@ -29,15 +29,15 @@ class Plugin(Plugin):
         self.renderer = Renderer(self)
 
     def get_patterns(self):
-        from django.conf.urls import url  # , include
+        from django.urls import re_path # , include
         from . import views
 
         Ticket = self.site.modules.tickets.Ticket
         urlpatterns = [
-            url(r'^$',
+            re_path(r'^$',
                 views.Index.as_view(),
                 name='index'),
-            url(r'^ticket/(?P<pk>[0-9]+)/$',
+            re_path(r'^ticket/(?P<pk>[0-9]+)/$',
                 views.Detail.as_view(model=Ticket)),
             # url('', include('lino.core.urls'))
         ]
